import unittest
import sys


class TestPlatform(unittest.TestCase):
    """Tests for the platform module."""

    def test_import(self):
        """Make sure we can import the platform module."""

        import ubuntuone.platform as uplt
        self.assertTrue(sys.platform.startswith(uplt.platform))
